@@ -2,7 +2,7 @@ def matrix():
     print(" Year: 2014 \n Board: CBSE \n CGPA: 10 \n School: Wisdom Public School \n City: Aligarh, Uttar Pradesh")
 
 
-def secondary():
+def senior_secondary():
     print(" Year: 2016 \n Board: CBSE \n Branch: PCM \n Percentge: 90.2% \n School: Sunbeam Academy, Samneghat \n City: Varansi, Uttar Pradesh")
 
 
